summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--ui/variablelist.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/ui/variablelist.h b/ui/variablelist.h
index 625bfd64..2f05f853 100644
--- a/ui/variablelist.h
+++ b/ui/variablelist.h
@@ -211,9 +211,12 @@ class BINARYNINJAUIAPI VariableList : public SidebarWidget, public FilterTarget
//! Show the rename dialog for the selected variable.
void changeSelectedVariableName();
//! Show the new type dialog for the seleected variable.
void changeSelectedVariableType();
+ //! Show the "merge variables" dialog for the selected variable.
+ void mergeSelectedVariable();
+
//! Clear the selected variable's name.
void clearSelectedVariableName();
@@ -211,9 +211,12 @@ class BINARYNINJAUIAPI VariableList : public SidebarWidget, public FilterTarget
//! Show the rename dialog for the selected variable.
void changeSelectedVariableName();
- //! Show the new type dialog for the seleected variable.
+ //! Show the new type dialog for the selected variable.
void changeSelectedVariableType();